From 0eb6f0190d04f7e102681a775a239a669de8554f Mon Sep 17 00:00:00 2001
From: Demian Katz <demian.katz@villanova.edu>
Date: Thu, 9 Jan 2014 12:34:40 -0500
Subject: [PATCH] More test coverage.

---
 .../src/VuFindTest/Record/RouterTest.php         | 16 +++++++++++++++-
 1 file changed, 15 insertions(+), 1 deletion(-)

diff --git a/module/VuFind/tests/unit-tests/src/VuFindTest/Record/RouterTest.php b/module/VuFind/tests/unit-tests/src/VuFindTest/Record/RouterTest.php
index 066c6f2c8e4..28439503fa5 100644
--- a/module/VuFind/tests/unit-tests/src/VuFindTest/Record/RouterTest.php
+++ b/module/VuFind/tests/unit-tests/src/VuFindTest/Record/RouterTest.php
@@ -61,7 +61,7 @@ class RouterTest extends TestCase
     }
 
     /**
      * Test routing with driver object.
      *
      * @return void
      */
@@ -74,6 +74,20 @@ class RouterTest extends TestCase
         );
     }
 
+    /**
+     * Test routing with id string having no source prefix.
+     *
+     * @return void
+     */
+    public function testRoutingWithStringMissingSource()
+    {
+        $router = $this->getRouter();
+        $this->assertEquals(
+            array('params' => array('id' => 'test'), 'route' => 'record'),
+            $router->getRouteDetails('test')
+        );
+    }
+
     /**
      * Test action routing with driver object.
      *
@@ -61,7 +61,7 @@ class RouterTest extends TestCase
 
     /**
-     * Test routing with driver object.
+     * Test routing with source|id string.
      *
      * @return void
-- 
GitLab